//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Auto_Size_Column
{
    public partial class Form1 : Form
    {
        #region Initialization
        public Form1()
        {
            InitializeComponent();

            this.listView1.AllowSubItemFocus = true;
            this.listView1.LabelEdit = true;

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   In this sample we will show you how to enable columns to automatically or manually change its width to fit its content.</p><br></br>";
            content += "<p>   By default all columns are not auto-sizable. You need to select a specific column and enable this by checking the 'Enable AutoSizable' check box. Then if you select and click on some subitem, a label edit will pop-up where you can change the subitem text. By pressing ENTER, you will notice that the column will automatically change its width.</p><br></br>";
            content += "<p>   In second example, first make sure the 'Label Edit' check box is unchecked. This will prevent interfering with first example. You can manually change the column width, by changing the subitem text from control panel on right, and by pressing the 'Manual AutoSize' button, the column will auto-size its width.</p><br></br>";
            content += "<p>   Finally, if you double-click on column header right, a few pixels from header right line, the column with auto-size its width.</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr><td width=\"100%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/listview/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
                System.Diagnostics.Process.Start((e.Object as LinkLabel).Links[0].LinkData.ToString());
        }

        private void InitList()
        {
            this.listView1.SuspendUpdate();

            LidorSystems.IntegralUI.Lists.ListViewColumn column = null;
            for (int j = 0; j < 3; j++)
            {
                column = new LidorSystems.IntegralUI.Lists.ListViewColumn("Column " + j.ToString(), "Footer " + j.ToString());
                column.Width = 100;

                this.listView1.Columns.Add(column);
                comboColumns.Items.Add(column.HeaderText);
            }


            LidorSystems.IntegralUI.Lists.ListViewItem item = null;
            LidorSystems.IntegralUI.Lists.ListViewSubItem subItem = null;

            for (int i = 0; i < 100; i++)
            {
                item = new LidorSystems.IntegralUI.Lists.ListViewItem("Item " + i.ToString());

                for (int j = 0; j < this.listView1.Columns.Count; j++)
                {
                    subItem = new LidorSystems.IntegralUI.Lists.ListViewSubItem("Item" + i.ToString() + j.ToString());
                    item.SubItems.Add(subItem);
                }

                this.listView1.Items.Add(item);
            }

            this.listView1.ResumeUpdate();
        }
        #endregion

        #region Functionality
        private void cbLabelEdit_CheckedChanged(object sender, EventArgs e)
        {
            this.listView1.LabelEdit = cbLabelEdit.Checked;
        }
        
        private void comboColumns_SelectedIndexChanged(object sender, EventArgs e)
        {
            int colIndex = comboColumns.SelectedIndex;
            if (colIndex >= 0 && colIndex < this.listView1.Columns.Count)
                cbAutoSizable.Checked = this.listView1.Columns[colIndex].AutoSizable;
        }

        private void btnEnableAutoSize_Click(object sender, EventArgs e)
        {
            int colIndex = comboColumns.SelectedIndex;
            if (colIndex >= 0 && colIndex < this.listView1.Columns.Count)
            {
                // Enable column to automatically change its to fit its content
                this.listView1.Columns[colIndex].AutoSizable = cbAutoSizable.Checked;

                // Update the control
                this.listView1.UpdateLayout();
            }
        }

        private void listView1_AfterSubItemSelect(object sender, LidorSystems.IntegralUI.ObjectEventArgs e)
        {
            if (e.Object is LidorSystems.IntegralUI.Lists.ListViewSubItem)
            {
                LidorSystems.IntegralUI.Lists.ListViewSubItem subItem = (LidorSystems.IntegralUI.Lists.ListViewSubItem)e.Object;

                tbSubItem.Text = subItem.Text;
            }
        }

        private void btnManualAutoSize_Click(object sender, EventArgs e)
        {
            if (this.listView1.SelectedSubItem != null)
            {
                this.listView1.SelectedSubItem.Text = tbSubItem.Text;

                // Manually auto-size column width to accommodate its content
                this.listView1.AutoSizeColumn(this.listView1.SelectedSubItem.Index);
            }
        }
        #endregion
    }
}